# streamlit-custom-component

Streamlit component that allows you to do X

## Installation instructions

```sh
pip install st_discord_nav
```

## Usage instructions

```python
import streamlit as st

from st_discord_nav import st_discord_nav

page = st_discord_nav()

```
